# Boomtils

please send help

useless package made by real.iusebako on discord

## how does it work?

like this
```python
from boomtils.lay_down_the_beat import letslaydownthebeat

letslaydownthebeat(5)
```


## please excuse me for my horrible readme skills
thank you

### update 1.70 had to be released due to the readme being incorrectly capitalized. whoopsies!